# cleandoc

Python package leveraging doq, black, pylint, mypy and sphinx to automatically clean and document python code.

## Install

pip install cleandoc

## Usage

cleandoc [-h] [-file FILE] [-dir DIR] [-write] [-ignore] [-noclean] [-nodoc]

optional arguments:
&emsp;-h, --help
&emsp;&emsp;&emsp;show this help message and exit\
&emsp;-file FILE,-f FILE
&emsp;&emsp;&emsp;Python (.py) file to clean\
&emsp;-dir DIR, -d DIR
&emsp;&emsp;&emsp;Directory containing Python (.py) files to clean and/or document\
&emsp;-write, -w
&emsp;&emsp;&emsp;Flag to write changes to files in-place\
&emsp;-ignore, -i
&emsp;&emsp;&emsp;Flag to continue through warnings\
&emsp;-noclean, -nc
&emsp;&emsp;&emsp;Flag to prevent cleaning of py files\
&emsp;-nodoc, -nd
&emsp;&emsp;&emsp;Flag to prevent html doc creation\

## Read The Docs

Download "docs" folder or [check preview](https://htmlpreview.github.io/?https://github.com/jkrist2696/cleandoc/blob/main/docs/index.html).

## Contributing

Message me on Github.

## License

[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)

## Copyright:

(c) 2023, Jason Krist